// 两极分化指数的构建，参考《中国城乡居民收入极化的趋势及其分解：1988-2007年》
// 指标1：Foster & Wolfson (2010)
// 指标2：Silber et al. (2007)

// do 变量导入

// 此为筛选过后的数据
use $DATA_FILEDIR\CHIP原数据及处理\2002_heckman.dta, clear
foreach w in 2007 2008 2013 {
	app using $DATA_FILEDIR\CHIP原数据及处理\\`w'_heckman.dta
}

// 收入按照2002年的价格水平进行平减
replace wage = wage if year == 2002
replace wage = wage / 1.137493 if year == 2007
replace wage = wage / 1.20415 if year == 2008
replace wage = wage / 1.371666 if year == 2013

// 将07年与08年的数据合并为2007
recode year 2008 = 2007

keep year province wage
tab province, g (province_)

qui keep if year == 2002
foreach i in 1 2 3 5 7 9 10 12 13 14 15 16 {
	tempfile file
	preserve
	qui keep if province_`i' == 1
	// ipolfw wage
	// ipolder wage, alpha(0.5)
	igini wage
	// centile wage
	// qui g dep = wage >= r(c_1)
	// diginig wage, hgroup(dep)
	restore
}

qui keep if year == 2007
foreach i in 4 5 6 7 9 10 12 13 14 {
	tempfile file
	preserve
	qui keep if province_`i' == 1
	// ipolfw wage
	// ipolder wage, alpha(0.5)
	igini wage
	// centile wage
	// qui g dep = wage >= r(c_1)
	// diginig wage, hgroup(dep)
	restore
}

qui keep if year == 2013
foreach i in 1 2 3 5 7 8 9 10 11 12 13 14 15 16 {
	tempfile file
	preserve
	qui keep if province_`i' == 1
	// ipolfw wage
	// ipolder wage, alpha(0.5)
	igini wage
	// centile wage
	// qui g dep = wage >= r(c_1)
	// diginig wage, hgroup(dep)
	restore
}

bysort year province : egen meanwage = mean(wage)
bysort year province : egen wage_p50 = pctile(wage), p(50)
duplicates drop year province, force

// ----------------------------------------------------------------------------------------------------------------------  //
// 主回归结果以及稳健性检验

do 变量导入

// 剔除所有无效数据
egen mis = rowmiss(_all)
drop if mis
drop mis

merge m:1 year province using $FILEDIR\垂直专业化贸易指数\polarization_Index.dta, nogen

foreach k in txt xml {
	capture confirm file $DATA_SAVING\极化指数.`k'
	if _rc == 0 {
		erase $DATA_SAVING\极化指数.`k'
	}
}

g wenjian_WaiBao = (im_feed_trade + im_assem_trade + ex_feed_trade + ex_assem_trade + ex_discharge_trade + ex_export_goods) / (im_all_trade + ex_all_trade)
g yiban_trade = ex_normal_trade / (im_all_trade + ex_all_trade)

// 极化指标后面加上2代表按照无筛选数据计算得到的极化指标数据
foreach i in fw2010_rel fw1992 der der_alienation der_identification fw2010_abs silber_abs silber_rel  fw2010_rel2 fw19922 der2 der_alienation2 der_identification2 fw2010_abs2 silber_abs2 silber_rel2 ///
 WaiBao im_WaiBao ex_WaiBao wenjian_WaiBao yiban_trade TC STC LC FDI FDL EL exp exp_sq IV {
	bys year : egen `i'_mean = mean(`i')
	bys year : egen `i'_sd = sd(`i')
	g `i'_std = (`i' - `i'_mean) / `i'_sd
	drop `i'_mean `i'_sd
}

local waibao = "WaiBao"
// local waibao = "im_WaiBao"
// local waibao = "ex_WaiBao"
// local waibao = "wenjian_WaiBao"
// local waibao = "yiban_trade"

// foreach i in 2002 2007 2013 {
// 	// local i = 2007
// 	qui reg fw2010_abs2_std `waibao'_std FDI_std STC_std LC_std FDL_std EL_std gender exp_std exp_sq_std i.education i.occupation i.guimo i.ownership i.industry i.place if year == `i', cl(province)
// 	outreg2 using $DATA_SAVING\极化指数.xml, bdec(3) sdec(3) adjr2
// }

qui reghdfe fw2010_abs2_std `waibao'_std FDI_std STC_std LC_std FDL_std EL_std gender exp_std exp_sq_std, absorb( education occupation guimo ownership industry ) cluster(province year)
outreg2 using $DATA_SAVING\极化指数.xml, bdec(3) sdec(3) adjr2
qui reghdfe fw2010_abs2_std `waibao'_std FDI_std STC_std LC_std FDL_std EL_std gender exp_std exp_sq_std, absorb( education occupation guimo ownership industry place) cluster(province year)
outreg2 using $DATA_SAVING\极化指数.xml, bdec(3) sdec(3) adjr2
qui reghdfe fw2010_abs2_std `waibao'_std FDI_std STC_std LC_std FDL_std EL_std gender exp_std exp_sq_std, absorb( education occupation guimo ownership industry place year) cluster(province year)
outreg2 using $DATA_SAVING\极化指数.xml, bdec(3) sdec(3) adjr2

// -------------------------------------------------------------工具变量生成---------------------------------------------------------  //
do Main_heckman
duplicates drop year province, force

egen mis = rowmiss(_all)
drop if mis

local waibao = "ex_WaiBao"

bysort year : egen `waibao'_sum = sum(`waibao')
g `waibao'_r = `waibao'_sum - `waibao'
bysort year : g `waibao'_r_a = `waibao'_r / _N
keep year province `waibao'_r_a
save C:\Users\L.V\Desktop\垂直专业化贸易指数\承接外包工具变量.dta, replace
// -------------------------------------------------------------2SLS---------------------------------------------------------  //
do 变量导入

// 剔除所有无效数据
egen mis = rowmiss(_all)
drop if mis
drop mis

merge m:1 year province using C:\Users\L.V\Desktop\垂直专业化贸易指数\polarization_Index.dta, nogen
merge m:1 year province using C:\Users\L.V\Desktop\垂直专业化贸易指数\承接外包工具变量.dta, nogen

foreach k in txt xml {
	capture confirm file $DATA_SAVING\极化指数.`k'
	if _rc == 0 {
		erase $DATA_SAVING\极化指数.`k'
	}
}

g wenjian_WaiBao = (im_feed_trade + im_assem_trade + ex_feed_trade + ex_assem_trade + ex_discharge_trade + ex_export_goods) / (im_all_trade + ex_all_trade)
g yiban_trade = ex_normal_trade / (im_all_trade + ex_all_trade)

// 极化指标后面加上2代表按照无筛选数据计算得到的极化指标数据
foreach i in fw2010_rel fw1992 der der_alienation der_identification fw2010_abs silber_abs silber_rel  fw2010_rel2 fw19922 der2 der_alienation2 der_identification2 fw2010_abs2 silber_abs2 silber_rel2 ///
 WaiBao im_WaiBao ex_WaiBao wenjian_WaiBao yiban_trade TC STC LC FDI FDL EL exp exp_sq IV {
	bys year : egen `i'_mean = mean(`i')
	bys year : egen `i'_sd = sd(`i')
	g `i'_std = (`i' - `i'_mean) / `i'_sd
	drop `i'_mean `i'_sd
}

local waibao = "WaiBao"

local iv = "WaiBao_r_a"

ivreghdfe fw2010_abs2_std TC_std FDI_std STC_std LC_std FDL_std EL_std gender exp_std exp_sq_std (`waibao'_std = `iv'), absorb( education occupation guimo ownership industry place year) cluster(province year)
outreg2 using $DATA_SAVING\极化指数.xml, bdec(3) sdec(3) adjr2
ivreghdfe fw19922_std TC_std FDI_std STC_std LC_std FDL_std EL_std gender exp_std exp_sq_std (`waibao'_std = `iv'), absorb( education occupation guimo ownership industry place year) cluster(province year)
outreg2 using $DATA_SAVING\极化指数.xml, bdec(3) sdec(3) adjr2
ivreghdfe der2_std TC_std FDI_std STC_std LC_std FDL_std EL_std gender exp_std exp_sq_std (`waibao'_std = `iv'), absorb( education occupation guimo ownership industry place year) cluster(province year)
outreg2 using $DATA_SAVING\极化指数.xml, bdec(3) sdec(3) adjr2
ivreghdfe der_identification2_std TC_std FDI_std STC_std LC_std FDL_std EL_std gender exp_std exp_sq_std (`waibao'_std = `iv'), absorb( education occupation guimo ownership industry place year) cluster(province year)
outreg2 using $DATA_SAVING\极化指数.xml, bdec(3) sdec(3) adjr2
ivreghdfe der_alienation2_std TC_std FDI_std STC_std LC_std FDL_std EL_std gender exp_std exp_sq_std (`waibao'_std = `iv'), absorb( education occupation guimo ownership industry place year) cluster(province year)
outreg2 using $DATA_SAVING\极化指数.xml, bdec(3) sdec(3) adjr2

// ----------------------------------------------------------------------------------------------------------------------  //
// 统计性描述

do 变量导入

// 剔除所有无效数据
egen mis = rowmiss(_all)
drop if mis
drop mis

merge m:1 year province using C:\Users\L.V\Desktop\垂直专业化贸易指数\polarization_Index.dta, nogen

duplicates drop year province, force

sort year province

foreach i in WaiBao im_WaiBao ex_WaiBao fw2010_rel2 fw19922 der2 der_alienation2 der_identification2 fw2010_abs2 silber_abs2 silber_rel2 {
	by year : egen m_`i' = mean(`i')
}

duplicates drop year, force

// ----------------------------------------------------------------------------------------------------------------------  //
// 极化指数分年估计

// 此为筛选过后的数据
use $DATA_FILEDIR\CHIP原数据及处理\2002_heckman.dta, clear
foreach w in 2007 2008 2013 {
	app using $DATA_FILEDIR\CHIP原数据及处理\\`w'_heckman.dta
}

// 收入按照2002年的价格水平进行平减
replace wage = wage if year == 2002
replace wage = wage / 1.137493 if year == 2007
replace wage = wage / 1.20415 if year == 2008
replace wage = wage / 1.371666 if year == 2013

// 将07年与08年的数据合并为2007
recode year 2008 = 2007

// bysort year : egen meanwage = mean(wage)
// bysort year : egen wage_p50 = pctile(wage), p(50)
// duplicates drop year, force

foreach i in 2002 2007 2013 {
	tempfile file
	preserve
	qui keep if year == `i'
	// ipolfw wage
	// ipolder wage, alpha(0.5)
	igini wage
	// centile wage
	// qui g dep = wage >= r(c_1)
	// diginig wage, hgroup(dep)
	restore
}

// ----------------------------------------------------------------------------------------------------------------------  //
// 极化指数分年估计
// 分职业、教育、行业

// 此为筛选过后的数据
use $DATA_FILEDIR\CHIP原数据及处理\2002_heckman.dta, clear
foreach w in 2007 2008 2013 {
	app using $DATA_FILEDIR\CHIP原数据及处理\\`w'_heckman.dta
}

// 收入按照2002年的价格水平进行平减
replace wage = wage if year == 2002
replace wage = wage / 1.137493 if year == 2007
replace wage = wage / 1.20415 if year == 2008
replace wage = wage / 1.371666 if year == 2013

// 将07年与08年的数据合并为2007
recode year 2008 = 2007

// local fenzu = "occupation"
local fenzu = "education"
// local fenzu = "industry"

foreach i in 2002 2007 2013 {
	tempfile file
	preserve
	qui keep if year == `i'
	bys province `fenzu' : g hweight = _N
	bys province `fenzu' : egen wage_mean = mean(wage)
	duplicates drop `fenzu', force
	// ipolder wage_mean, hsize(hweight)
	// ipolfw wage_mean, hsize(hweight)
	igini wage_mean, hsize(hweight)
	restore
}
