global DATA_FILEDIR "D:\垂直专业化贸易指数\"
global FILEDIR "D:\"
global DATA_SAVING "D:\垂直专业化贸易指数\数据存储\"

// 此为筛选过后的数据
use $DATA_FILEDIR\CHIP原数据及处理\2002_heckman.dta, clear
foreach w in 2007 2008 2013 {
	app using $DATA_FILEDIR\CHIP原数据及处理\\`w'_heckman.dta
}

// 下面整合的均为滞后一期的变量
replace year = year - 1

merge m:1 year province using $FILEDIRG\完成论文存档\承接离岸外包、常规任务偏向型技术进步与工资极化\数据\\工经数据.dta, nogen

drop DB1-MQ CHAV-CCR
label variable CH "生活成本"

foreach w in FDI 分省金融机构存贷款年末余额 进出口总额 分省名义GDP 出口贸易细分项 进口贸易细分项 规模以上企业总产值 设备资本存量 专利申请授权数 ///
资本劳动比率 劳动生产率 规模以上企业主营业务收入 分省第二产业增加值 分省第三产业增加值 DEA数据 垂直专业化贸易指数 分省教育经费收入 分省地方财政一般预算支出 {
	merge m:1 year province using $FILEDIR\数据\数据存档\宏观数据\\`w'.dta, nogen
}
merge m:1 year using $FILEDIR\数据\数据存档\宏观数据\汇率.dta, nogen
merge m:1 province using $FILEDIR\数据\数据存档\宏观数据\分省省会至海岸线距离.dta, nogen

// 垂直专业化贸易指数同样经过了滞后一期处理，在EXCEL中完成
// 最低工资为当期值
replace year = year + 1

// 内生性检验用
merge m:1 year province using $FILEDIR\完成论文存档\承接离岸外包、常规任务偏向型技术进步与工资极化\初步结果\财贸经济\承接外包工具变量.dta, nogen

merge m:1 year province using $FILEDIR\数据\数据存档\宏观数据\\最低工资.dta, nogen

// 删除空值
keep if year == 2002 | year == 2007 | year == 2008 | year == 2013

// 外包指标（按照张少军做法）
g WaiBao = (im_feed_trade + im_assem_trade + ex_feed_trade + ex_assem_trade) / (im_all_trade + ex_all_trade)
label variable WaiBao "垂直专业化分工"

// 离岸外包
g im_WaiBao = (im_feed_trade + im_assem_trade) / (im_all_trade + ex_all_trade)
label variable im_WaiBao "离岸外包"

// 承接外包
g ex_WaiBao = (ex_feed_trade + ex_assem_trade) / (im_all_trade + ex_all_trade)
label variable ex_WaiBao "承接外包"

// ECS
g ECS = ecs / ngdp
label variable ECS "资本累积：设备资本存量/GDP"

// FDI
g FDI = fdi * er / ngdp
label variable FDI "外商直接投资/GDP"

// TRA
g TRA = imex_all * er / ngdp / 10000
label variable TRA "贸易开放度/GDP"

// SER
g STC = (ngdp - sec_indu - ser) / ngdp + 2 * sec_indu / ngdp + 3 * ser / ngdp
label variable STC "产业结构升级"

// CH
replace CH = CH / 100
rename CH LC

// TFPCH
rename tfpch TC

// TECHCH
rename techch TECHCH

// LPI
rename lpi LPI

// CAP_LAB
rename cap_lab CAP_LAB

// CAP_LAB
rename zhuanli ZHL

g FDL = (deposit + loan) / ngdp
label variable FDL "分省金融机构存贷款年末余额/GDP"

g EL = edu_spend / gov_out
label variable EL "教育支出"

// 按照刘修岩在《中国工业经济》上的做法，设定如下工具变量以同时控制国外市场接近度以及时间变化量
g IV = log(1/dist_shore) * 1/er
label variable IV "工具变量"

// 删除低于50%最低工资的样本
drop if wage >= 0 & wage <= low_wage * 6

// 稳健性检验：剔除工资水平低于100的群体
// keep if wage >= 100

// 从1至5分别是从低至高
// 1.商业、服务业人员 2.生产、运输设备操作人员及有关人员 3.办事人员和有关人员 4.专业技术人员 5.国家机关党群组织、企事业单位负责人 
keep if (occupation >= 1 & occupation <= 4 | occupation == 6)
recode occupation 1 = 5 2 = 4 3 = 3 6 = 2 4 = 1
tab occupation, g (occ_)

// 设定企业规模，1至3分别从低至高
recode guimo (1 = 1) (2/3 = 2) (4 = 3)
tab guimo, g(gm_)

// 设定企业所有制，1至3分别从低至高
recode ownership (1/2 = 1) (3 = 2) (4 = 3)
tab ownership, g(own_)

// 数据基本处理及虚拟变量生成
recode gender 1 = 1 2 = 0

// 省份保留一致
// keep if province == 32 | province == 34 | province == 41 | province == 42 | province == 44 | province == 50 | province == 51

// 按照罗楚亮(2018)的做法，保留四个年份中存在两个以上相同省份的数据
drop if province == 37 | province == 43
// winsor2 lnwage, replace cuts(1 99) trim by(year province)

tab province, g (province_)
tab place, g (place_)

// 生成教育水平
// tab education, g (edu_)
g edu_level = education
recode edu_level (1 = 0)(2 = 6)(3 = 9)(4/5 = 12)(6 = 15)(7 = 16)(8 = 19)
label variable edu_level "受教育年限"

// 将教育分为3部分 从低至高分别为
// 初中及以下学历、高中以及中专学历、大专及以上学历
recode education (1/3 = 1)(4/5 = 2)(6/8 = 3)
tab education, g (edu_)

// 生成经验变量
g exp = age - edu_level - 6
g exp_sq = exp ^ 2 / 100

// 生成八大区域
// g eight_place = province
// recode eight_place (21/23 = 1)(11/13 37 = 2)(31/33 = 3)(35 44 46 = 4)(14 15 41 61 = 5)(34 36 42 43 = 6)(45 50/53 = 7)(54 62/65 = 8)
tab eight_place, g (ep_)

drop if industry == 1
tab industry, g (indu_)

// 收入按照2002年的价格水平进行平减
replace wage = wage if year == 2002
replace wage = wage / 1.137493 if year == 2007
replace wage = wage / 1.20415 if year == 2008
replace wage = wage / 1.371666 if year == 2013

// 将07年与08年的数据合并为2007
// recode year 2008 = 2007
drop if year == 2008
tab year, g (year_)

// 设置对数工资
g lnwage = log(wage)

// 图片格式的预先设定
set scheme sj
grstyle init
grstyle set plain, horizontal grid //设置背景和坐标系

/*查看所有宏变量，包括局部变量和全局变量*/ 
// replace tech_i = log(dea_tech)
// macro list

egen mis_other = rowmiss(guimo-allworktime ownership-year_3)
// egen mis_other = rowmiss(guimo-allworktime ownership-year_2)
drop if mis_other
drop mis_other

sort year wage
